aboutsummaryrefslogtreecommitdiffstats
path: root/src/threadlistview.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/threadlistview.cpp')
-rw-r--r--src/threadlistview.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/threadlistview.cpp b/src/threadlistview.cpp
index 5a3ce77..019d7c9 100644
--- a/src/threadlistview.cpp
+++ b/src/threadlistview.cpp
@@ -27,10 +27,10 @@ void ThreadListView::mousePressEvent(QMouseEvent *event)
{
const QModelIndex index = indexAt(event->pos());
// The reply count IS the expander. Anything outside its rect selects the
// card and opens it, which is what the rest of the card is for.
if (event->button() == Qt::LeftButton && index.isValid()
- && index.data(ThreadListModel::ReplyCountRole).toInt() > 0) {
+ && index.data(ThreadListModel::MessageCountRole).toInt() > 0) {
QStyleOptionViewItem option;
initViewItemOption(&option);
@@ -27,10 +27,10 @@ void ThreadListView::mousePressEvent(QMouseEvent *event)
{
const QModelIndex index = indexAt(event->pos());
- // The reply count IS the expander. Anything outside its rect selects the
+ // The message count IS the expander. Anything outside its rect selects the
// card and opens it, which is what the rest of the card is for.
if (event->button() == Qt::LeftButton && index.isValid()